@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -39,14 +39,10 @@
 #include <sys/utsname.h>    /* for uname() */
 #endif
 #include <sys/types.h>
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>         /* Unix header for getpid() */
-#endif
 #ifdef G_OS_WIN32
 #include <winsock2.h>
 #include <ws2tcpip.h>
-#include <process.h>
-#define getpid() _getpid()
 #endif
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
@@ -229,10 +225,13 @@ typedef struct _date_token {
 static date_token *
 datetok (const char *date)
 {
-	date_token *tokens = NULL, *token, *tail = (date_token *) &tokens;
+	date_token tokens, *token, *tail;
 	const char *start, *end;
         unsigned char mask;
 	
+	tail = (date_token *) &tokens;
+	tokens.next = NULL;
+	
 	start = date;
 	while (*start) {
 		/* kill leading whitespace */
@@ -266,7 +265,7 @@ datetok (const char *date)
 			break;
 	}
 	
-	return tokens;
+	return tokens.next;
 }
 
 static int
@@ -999,14 +998,14 @@ g_mime_utils_decode_message_id (const char *message_id)
 GMimeReferences *
 g_mime_references_decode (const char *text)
 {
-	GMimeReferences *refs, *tail, *ref;
+	GMimeReferences refs, *tail, *ref;
 	const char *word, *inptr = text;
 	char *msgid;
 	
 	g_return_val_if_fail (text != NULL, NULL);
 	
-	refs = NULL;
 	tail = (GMimeReferences *) &refs;
+	refs.next = NULL;
 	
 	while (*inptr) {
 		decode_lwsp (&inptr);
@@ -1031,7 +1030,7 @@ g_mime_references_decode (const char *text)
 		}
 	}
 	
-	return refs;
+	return refs.next;
 }
 
 
@@ -2475,13 +2474,13 @@ typedef struct _rfc822_word {
 static rfc822_word *
 rfc2047_encode_get_rfc822_words (const char *in, gboolean phrase)
 {
-	rfc822_word *words, *tail, *word;
+	rfc822_word words, *tail, *word;
 	rfc822_word_t type = WORD_ATOM;
 	const char *inptr, *start, *last;
 	int count = 0, encoding = 0;
 	
-	words = NULL;
 	tail = (rfc822_word *) &words;
+	words.next = NULL;
 	
 	last = start = inptr = in;
 	while (inptr && *inptr) {
@@ -2566,7 +2565,7 @@ rfc2047_encode_get_rfc822_words (const char *in, gboolean phrase)
 	
 #if d(!)0
 	printf ("rfc822 word tokens:\n");
-	word = words;
+	word = words.next;
 	while (word) {
 		printf ("\t'%.*s'; type=%d, encoding=%d\n",
 			word->end - word->start, word->start,
@@ -2576,7 +2575,7 @@ rfc2047_encode_get_rfc822_words (const char *in, gboolean phrase)
 	}
 #endif
 	
-	return words;
+	return words.next;
 }
 
 #define MERGED_WORD_LT_FOLDLEN(wlen, type) ((type) == WORD_2047 ? (wlen) < GMIME_FOLD_PREENCODED : (wlen) < (GMIME_FOLD_LEN - 8))
